@@ -1,10 +1,8 @@
 -- Arbitrary.hs: QuickCheck instances
--- Copyright © 2014-2016  Clint Adams
+-- Copyright © 2014-2018  Clint Adams
 -- This software is released under the terms of the Expat license.
 -- (See the LICENSE file).
 
-{-# LANGUAGE CPP #-}
-
 module Codec.Encryption.OpenPGP.Arbitrary () where
 
 import Codec.Encryption.OpenPGP.Types
@@ -171,9 +169,3 @@ instance Arbitrary NotationName where
 
 instance Arbitrary NotationValue where
     arbitrary = fmap NotationValue arbitrary
-
-#if !MIN_VERSION_QuickCheck(2,9,0)
--- FIXME: this should be elsewhere
-instance Arbitrary a => Arbitrary (NE.NonEmpty a) where
-    arbitrary = NE.fromList `fmap` listOf1 arbitrary
-#endif
