@@ -1,10 +1,8 @@
 -- Signatures.hs: OpenPGP (RFC4880) signature verification
--- Copyright © 2012-2016  Clint Adams
+-- Copyright © 2012-2018  Clint Adams
 -- This software is released under the terms of the Expat license.
 -- (See the LICENSE file).
 
-{-# LANGUAGE CPP #-}
-
 module Codec.Encryption.OpenPGP.Signatures (
    verifySigWith
  , verifyAgainstKeyring
@@ -12,9 +10,6 @@ module Codec.Encryption.OpenPGP.Signatures (
  , verifyTKWith
 ) where
 
-#if !MIN_VERSION_base(4,8,0)
-import Control.Applicative ((<$>), (<*>))
-#endif
 import Control.Error.Util (hush)
 import Control.Lens ((^.), _1)
 import Control.Monad (liftM2)
@@ -27,12 +22,7 @@ import qualified Crypto.PubKey.RSA.PKCS15 as P15
 
 import Data.ByteString.Lazy (ByteString)
 import qualified Data.ByteString.Lazy as BL
-import Data.Either (lefts, rights)
-#if MIN_VERSION_base(4,7,0)
-import Data.Either (isRight)
-#else
-import Control.Error.Util (isRight)
-#endif
+import Data.Either (isRight, lefts, rights)
 import Data.IxSet.Typed ((@=))
 import qualified Data.IxSet.Typed as IxSet
 import Data.List.NonEmpty (NonEmpty(..))
