@@ -1,5 +1,5 @@
 -- Filter.hs: OpenPGP (RFC4880) packet filtering
--- Copyright © 2014-2015  Clint Adams
+-- Copyright © 2014-2018  Clint Adams
 -- This software is released under the terms of the Expat license.
 -- (See the LICENSE file).
 
@@ -12,7 +12,7 @@ module Data.Conduit.OpenPGP.Filter (
 ) where
 
 import Control.Monad.Trans.Reader (Reader, runReader)
-import Data.Conduit (Conduit)
+import Data.Conduit (ConduitT)
 import qualified Data.Conduit.List as CL
 
 import Codec.Encryption.OpenPGP.Types
@@ -22,14 +22,14 @@ data FilterPredicates =
     RTKFilterPredicate (Reader TK Bool)       -- ^ fp for transferable keys
   | RPFilterPredicate (Reader Pkt Bool)       -- ^ fp for context-less packets
 
-conduitPktFilter :: Monad m => FilterPredicates -> Conduit Pkt m Pkt
+conduitPktFilter :: Monad m => FilterPredicates -> ConduitT Pkt Pkt m ()
 conduitPktFilter = CL.filter . superPredicate
 
 superPredicate :: FilterPredicates -> Pkt -> Bool
 superPredicate (RPFilterPredicate e) p = runReader e p
 superPredicate _ _ = False   -- do not match incorrect type of packet
 
-conduitTKFilter :: Monad m => FilterPredicates -> Conduit TK m TK
+conduitTKFilter :: Monad m => FilterPredicates -> ConduitT TK TK m ()
 conduitTKFilter = CL.filter . superTKPredicate
 
 superTKPredicate :: FilterPredicates -> TK -> Bool
